#
# spec file for package byacc
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2010 Guido Berhoerster.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           byacc
Version:        20240109
Release:        1.2
Summary:        LALR(1) parser generator
License:        SUSE-Public-Domain
Group:          Development/Languages/C and C++
URL:            https://invisible-island.net/byacc/byacc.html
Source0:        https://invisible-mirror.net/archives/byacc/byacc-%{version}.tgz
Source1:        https://invisible-mirror.net/archives/byacc/byacc-%{version}.tgz.asc
Source2:        %{name}.keyring

%description
Berkeley Yacc is a LALR(1) parser generator. It has been made as compatible as
possible with AT&T Yacc and it accepts any input specification that conforms to
the AT&T Yacc documentation. In contrast to bison, it is written to avoid
dependencies upon a particular compiler.

%prep
%setup -q

%build
# without --with-warnings several functions will not be marked with gcc's
# noreturn attribute and produce warnings when $RPM_OPT_FLAGS contains -Wall
%configure \
  --with-warnings \
  --enable-btyacc \
	--program-prefix=b
%make_build

%install
%make_install

%check
%make_build check

%files
%doc ACKNOWLEDGEMENTS CHANGES NEW_FEATURES NO_WARRANTY NOTES README*
%{_bindir}/byacc
%{_mandir}/man1/byacc.1%{?ext_man}

%changelog
* Sun Mar 17 2024 Dirk Müller <dmueller@suse.com>
- update to 20240109:
  * maintenance updates
* Fri Jun  2 2023 Dirk Müller <dmueller@suse.com>
- update to 20230521:
  * error.c, defs.h, reader.c:
    allow @1 or $@ with a warning if no %%locations was given
  * reader.c: clear pointer in end_ainfo() after freeing it.
  * reader.c: report errors in %%define as "unexpected value"
    add/use macros begin_ainfo() and end_ainfo() to reduce clutter
  * defs.h, error.c: add function unexpected_value()
  * add %%nterm as an alias for %%type, since bison made that confusion.
  * reader.c:
    ensure that filler_buf and prefix_buf are initialized for the special case
    where they are empty (report by Martin Jansa, cf: 20230219)
  * output.c:
    make test-differences smaller when compiling with YY_NO_LEAKS by replacing
    a blank line with the generated #define rather than adding 3 lines.
  * reader.c:
    correct a use-after-free in more_curly, which could occur if a %%lex-param
    or %%parse-param was multi-line (Redhat #2183006).
  * main.c: rename no_space() to on_error()
  * error.c: rename no_space() to no_error(), handling any errno
  * defs.h: rename no_space() to on_error()
* Tue Mar  7 2023 Dirk Müller <dmueller@suse.com>
- update to 20230219:
  * maintenance updates
* Fri Feb 17 2023 Avinesh Kumar <avinesh.kumar@suse.com>
- update to 20230201:
  * configure.in: initialize $ac_includes_default
  * aclocal.m4: resync with my-autoconf
* Mon Jan  2 2023 Dirk Müller <dmueller@suse.com>
- update to 20221229:
  * autoconf update
  * configure.in:
    correct help-message for --disable-btyacc option, and fix the reporting of
    the selected option value in the configure script's output
* Sat Dec  3 2022 Dirk Müller <dmueller@suse.com>
- update to 20221106:
  * test/run_test.sh: use context diff, to work with AIX
  * defs.h:
    fprintf_lineno might be passed a null, when reading from stdin - show "(null)"
  * makefile.in, test/run_make.sh, test/run_test.sh, test/run_lint.sh:
    fgrep-fixes
  * yacc.1: mention use of stderr/stdout for usage/debugging
  * yacc.1: document %%empty
  * yacc.1: document %%debug
  * yacc.1: minor fixes with check-manpage
* Sat Jun 25 2022 Dirk Müller <dmueller@suse.com>
- update to 20220128:
  * change a few malloc's to calloc's so clang analyzer can see initialized data
  * modify address computation in closure.c to avoid undefined behavior on
    machines which do not support large offsets (analysis/patch by Jessica Clarke,
    cf: 2014-09-17)
  * testsuite and autotools/build script fixes
* Sat Oct 16 2021 Dirk Müller <dmueller@suse.com>
- update to 20210808:
  * main.c: account for a memory-leak
  * fix memory-leak when replacing $$'s in destructor code
  * main.c, yacc.1: add "-h" option
  * line number reporting fixes
* Tue Jul 27 2021 Dirk Müller <dmueller@suse.com>
- update to 20210619:
  * btyaccpar.skel, yaccpar.skel: cancel unused assignments
  * output.c: fix gcc warning
  * test/run_test.sh, test/run_lint.sh, test/run_make.sh:
    shellcheck-warnings
  * test/run_test.sh: changes suggested at
    https://github.com/jannick0/byacc-snapshots/tree/YYINT-fix-20210520
  * autotools update
* Sat May  8 2021 Dirk Müller <dmueller@suse.com>
- update to 20210328:
  * reader.c: ignore bison's "%%empty" extension
  * reader.c, defs.h:
    %%debug was a trivial bison "extension", mark it as such
  * yacc.1: use italics in a few places where bold was inappropriate
  * reader.c:
    add union tag to YYSTYPE structure for compatibility with a feature which
    bison copied from Solaris yacc (request by Ella Stanforth)
  * closure.c, warshall.c:
    fix undefined-behavior diagnosed with gcc -fsanitize=undefined (report by
    Alexander Richardson)
* Sun Sep 20 2020 Dirk Mueller <dmueller@suse.com>
- update to 20200910:
  * LICENSE: RCS_BASE
  * reader.c, output.c: cppcheck -- reduce scope
  update to version 2.0
  improve loop which skips backward through a (possibly nested) sequence of
  square-brackets.
  * reader.c: simplify a check to quiet a bogus cppcheck-warning
  * yacc.1: bump date
  * reader.c: add a note about a bogus cppcheck warning
  always check for gcc attributes, to work around defect in clang's imitation
  of this feature
  * reader.c: cppcheck -- scope reduction
  cppcheck -- eliminate bogus returns after no-return functions
  * verbose.c, output.c, mkpar.c, main.c, warshall.c, lr0.c, lalr.c, graph.c, closure.c:
  cppcheck -- scope reduction
* Fri Apr  3 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 20200330:
  * See attached CHANGES for complete list of changes
- Enable btyacc extension
* Fri Dec  6 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 20191125:
  * See attached CHANGES for complete list of changes
* Mon Jun 17 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 20190617:
  * See attached CHANGES for complete list of changes
* Wed Jul 11 2018 mpluskal@suse.com
- Update to version 20180609:
  * See attached CHANGES for complete list of changes
* Mon Jun  5 2017 mpluskal@suse.com
- Update to version 20170430:
  * See attached CHANGES for complete list of changes
* Fri Apr  7 2017 mpluskal@suse.com
- Update to version 20170201:
  * See attached CHANGES for complete list of changes
* Fri Jan 27 2017 mpluskal@suse.com
- Update to version 20161202:
  * See attached CHANGES for complete list of changes
* Tue Jul 12 2016 mpluskal@suse.com
- Update to version 20160606:
  * See attached CHANGES for complete list of changes
* Wed Aug  5 2015 mpluskal@suse.com
- Update to 20150711
  * See attached CHANGES for complete list of changes
* Thu Feb 26 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Add gpg signature
- Update to 20141128
  * lr0.c: coverity #39181: memory leak
- Changes in 2014-11-13
  * descrip.mms: support for openvms
* Fri Oct 10 2014 gber@opensuse.org
- update to version 20141006
  - package/debian/source/format: change to native format to work
    around regression in Debian packaging.
  - main.c: correct parameter for umask - for very old mkstemp's -
    and use type mode_t to quiet compiler warning
  - configure.in: add configure check for mode_t
  - reader.c: better fix for get_line, by ensuring there is enough
    space to null-terminate its result (prompted by discussion with
    Craig Rodrigues).
  - main.c: make change to umask before calling mkstemp, as
    suggested in Coverity #56902
  - reader.c: adjust logic in copy_action to avoid potential
    null-pointer dereference (Coverity #56901)
  - reader.c: adjust logic to avoid potential null-pointer
    dereference in compile_args (Coverity #63407)
  - reader.c: eliminate strcpy into fixed-size buffer (Coverity
    [#63408])
  - yacc.1: document changes made with respect to %%parse-param
  - output.c: add parameters from %%parse-param to destructor.  The
    order of the parameters is intentionally inconsistent with
    yyparse/yyerror, for "compatibility" with bison.
  - output.c: use puts_param_types/puts_param_names to output
    lex_param data.
  - btyaccpar.c: add casts, change types to fix strict compiler
    warnings
  - output.c: gcc-warning
  - output.c: fix limit when merging real/workaround tables
  - output.c: for btyacc, it is possible to have no conflicts - but
    in that case, the "ctable" was not generated at all, while the
    skeleton uses the table.  The most straightforward (workaround)
    is generating a dummy table which rejects any state.
  - test/btyacc_destroy3.y, test/btyacc_destroy2.y,
    test/btyacc_destroy1.y: fix "make check_make"
  - reader.c: trim blanks from interim value in copy_param() to
    handle special case when a space precedes a comma.
  - output.c: use two new functions, puts_param_types and
    puts_param_names, to improve format of the parse_param list (by
    trimming space after "*") as well as correcting the output of
    the comma-separated names (only the last name was output).
  - reader.c: modify copy_param() to handle resulting
    comma-separated list.  Before, it only expected a single
    parameter.
  - reader.c: split-out save_param() from copy_param()
  - reader.c: trim_blanks() did not always convert spaces - fix.
  - reader.c: fix some minor regressions with error-reporting
  - aclocal.m4: update CF_XOPEN_SOURCE for Unixware change from
    lynx
  - reader.c: modify copy_param() to accept multiple parameters,
    each in curly braces like recent bison, as well as honoring
    bison's undocumented feature to accept the parameters as a
    comma-separated list.
  - main.c, reader.c, defs.h: use calloc in get_line() when
    allocating line to ensure it is fully initialized, fixes a
    later uninitialized value in copy_param() (FreeBSD #193499).
  - closure.c, lalr.c, output.c, defs.h: rephrase odd addressing to
    fix Coverity #48848, #38950, #38860, not actually a bug.
  - config.sub: update to 2014-07-28
  - aclocal.m4: modified to support port to Minix3.2
* Tue Aug 26 2014 gber@opensuse.org
- update to version 20140715
  * fix tests
  * remove obsolete -D option from usage message
* Mon May 26 2014 gber@opensuse.org
- update to version 20140422
  * too large number of changes to list here, see the included
    CHANGES file for a detailed list
* Thu Sep 26 2013 gber@opensuse.org
- update to version 20130925
  * reader.c: fix two loop-limits found by clang 3.3 --analyze
  * configure: regen
  * aclocal.m4: tweaks to CF_MIXEDCASE_FILENAMES and
    CF_XOPEN_SOURCE for msys from ncurses
  * package/mingw-byacc.spec: RCS_BASE
  * regenerate various test files
  * skeleton.c: Increase default stack-size to match FreeBSD
    version noted as from "BSD 4.4 Lite Usr.bin Sources".
  * config.sub: update to 2013-09-15
  * config.guess: update to 2013-06-10
* Sat Aug  3 2013 crrodriguez@opensuse.org
- run test suite
- use --program-prefix instead of moving/renaming executables
  around.
* Sat Aug  3 2013 crrodriguez@opensuse.org
- byacc 20130304
  * too many since 2010 to list here.. see
  http://invisible-island.net/byacc/CHANGES
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Mon Mar 29 2010 guido+opensuse.org@berhoerster.name
- initial packaging of byacc
